# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSterkteklasseHout(KeuzelijstField):
    """De klasse die de maximale belasting van het hout aangeeft. Gebruik letter C voor naaldhout en D voor loofhout, gevolgd door een getal dat betrekking heeft op de karakteristieke buigspanning."""
    naam = 'KlSterkteklasseHout'
    label = 'Sterkteklasse van hout'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlSterkteklasseHout'
    definition = 'De klasse die de maximale belasting van het hout aangeeft. Gebruik letter C voor naaldhout en D voor loofhout, gevolgd door een getal dat betrekking heeft op de karakteristieke buigspanning.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSterkteklasseHout'
    options = {
        'c14': KeuzelijstWaarde(invulwaarde='c14',
                                label='C14',
                                status='ingebruik',
                                definitie='C staat voor naaldhout. 14 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/c14'),
        'c16': KeuzelijstWaarde(invulwaarde='c16',
                                label='C16',
                                status='ingebruik',
                                definitie='C staat voor naaldhout. 16 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/c16'),
        'c18': KeuzelijstWaarde(invulwaarde='c18',
                                label='C18',
                                status='ingebruik',
                                definitie='C staat voor naaldhout. 18 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/c18'),
        'c20': KeuzelijstWaarde(invulwaarde='c20',
                                label='C20',
                                status='ingebruik',
                                definitie='C staat voor naaldhout. 20 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/c20'),
        'c22': KeuzelijstWaarde(invulwaarde='c22',
                                label='C22',
                                status='ingebruik',
                                definitie='C staat voor naaldhout. 22 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/c22'),
        'c24': KeuzelijstWaarde(invulwaarde='c24',
                                label='C24',
                                status='ingebruik',
                                definitie='C staat voor naaldhout. 24 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/c24'),
        'c27': KeuzelijstWaarde(invulwaarde='c27',
                                label='C27',
                                status='ingebruik',
                                definitie='C staat voor naaldhout. 27 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/c27'),
        'c30': KeuzelijstWaarde(invulwaarde='c30',
                                label='C30',
                                status='ingebruik',
                                definitie='C staat voor naaldhout. 30 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/c30'),
        'c35': KeuzelijstWaarde(invulwaarde='c35',
                                label='C35',
                                status='ingebruik',
                                definitie='C staat voor naaldhout. 35 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/c35'),
        'c40': KeuzelijstWaarde(invulwaarde='c40',
                                label='C40',
                                status='ingebruik',
                                definitie='C staat voor naaldhout. 40 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/c40'),
        'c45': KeuzelijstWaarde(invulwaarde='c45',
                                label='C45',
                                status='ingebruik',
                                definitie='C staat voor naaldhout. 45 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/c45'),
        'c50': KeuzelijstWaarde(invulwaarde='c50',
                                label='C50',
                                status='ingebruik',
                                definitie='C staat voor naaldhout. 50 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/c50'),
        'd30': KeuzelijstWaarde(invulwaarde='d30',
                                label='D30',
                                status='ingebruik',
                                definitie='D staat voor loofhout. 30 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/d30'),
        'd35': KeuzelijstWaarde(invulwaarde='d35',
                                label='D35',
                                status='ingebruik',
                                definitie='D staat voor loofhout. 35 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/d35'),
        'd40': KeuzelijstWaarde(invulwaarde='d40',
                                label='D40',
                                status='ingebruik',
                                definitie='D staat voor loofhout. 40 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/d40'),
        'd50': KeuzelijstWaarde(invulwaarde='d50',
                                label='D50',
                                status='ingebruik',
                                definitie='D staat voor loofhout. 50 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/d50'),
        'd60': KeuzelijstWaarde(invulwaarde='d60',
                                label='D60',
                                status='ingebruik',
                                definitie='D staat voor loofhout. 60 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/d60'),
        'd70': KeuzelijstWaarde(invulwaarde='d70',
                                label='D70',
                                status='ingebruik',
                                definitie='D staat voor loofhout. 70 N/mm² (megaPascal) drukt de buigsterkte uit evenwijdig aan de vezel.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSterkteklasseHout/d70')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlExternedetectieAangeslotentoestel(KeuzelijstField):
    """Keuzelijst met de voorkomende types van aangesloten toestellen (trein, brug, FCD) aan een externe detectie."""
    naam = 'KlExternedetectieAangeslotentoestel'
    label = 'Externedetectie aangeslotentoestel'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlExternedetectieAangeslotentoestel'
    definition = 'Keuzelijst met de voorkomende types van aangesloten toestellen (trein, brug, FCD) aan een externe detectie.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlExternedetectieAangeslotentoestel'
    options = {
        'MIVB': KeuzelijstWaarde(invulwaarde='MIVB',
                                 label='MIVB',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlExternedetectieAangeslotentoestel/MIVB'),
        'brug': KeuzelijstWaarde(invulwaarde='brug',
                                 label='brug',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlExternedetectieAangeslotentoestel/brug'),
        'de-Lijn': KeuzelijstWaarde(invulwaarde='de-Lijn',
                                    label='de Lijn',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlExternedetectieAangeslotentoestel/de-Lijn'),
        'hulpdiensten': KeuzelijstWaarde(invulwaarde='hulpdiensten',
                                         label='hulpdiensten',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlExternedetectieAangeslotentoestel/hulpdiensten'),
        'luchthaven': KeuzelijstWaarde(invulwaarde='luchthaven',
                                       label='luchthaven',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlExternedetectieAangeslotentoestel/luchthaven'),
        'militaire-kazerne': KeuzelijstWaarde(invulwaarde='militaire-kazerne',
                                              label='militaire kazerne',
                                              status='ingebruik',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlExternedetectieAangeslotentoestel/militaire-kazerne'),
        'spoorweg': KeuzelijstWaarde(invulwaarde='spoorweg',
                                     label='spoorweg',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlExternedetectieAangeslotentoestel/spoorweg'),
        'tunnel': KeuzelijstWaarde(invulwaarde='tunnel',
                                   label='tunnel',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlExternedetectieAangeslotentoestel/tunnel')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBoomspiegelInvulling(KeuzelijstField):
    """Keuzelijst, die de manieren om de boomspiegel in te vullen, oplijst."""
    naam = 'KlBoomspiegelInvulling'
    label = 'Boomspiegel'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBoomspiegelInvulling'
    definition = 'Keuzelijst, die de manieren om de boomspiegel in te vullen, oplijst.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBoomspiegelInvulling'
    options = {
        'andere': KeuzelijstWaarde(invulwaarde='andere',
                                   label='andere',
                                   status='ingebruik',
                                   definitie='De boomspiegel bestaat uit ander materiaal dan opgelijst',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBoomspiegelInvulling/andere'),
        'beplanting': KeuzelijstWaarde(invulwaarde='beplanting',
                                       label='beplanting',
                                       status='ingebruik',
                                       definitie='De boomspiegel bestaat voornamelijk uit sierbeplanting of houtige vegetatie',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBoomspiegelInvulling/beplanting'),
        'biologisch-afbreekbaar-doek-PLA': KeuzelijstWaarde(invulwaarde='biologisch-afbreekbaar-doek-PLA',
                                                            label='biologisch afbreekbaar doek PLA',
                                                            status='ingebruik',
                                                            definitie='Afdekking van de bodem rond de boom met een biologisch afbreekbaar doek in PLA.',
                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBoomspiegelInvulling/biologisch-afbreekbaar-doek-PLA'),
        'biologisch-afbreekbaar-doek-jute': KeuzelijstWaarde(invulwaarde='biologisch-afbreekbaar-doek-jute',
                                                             label='biologisch afbreekbaar doek jute',
                                                             status='ingebruik',
                                                             definitie='Afdekking van de bodem rond de boom met een biologisch afbreekbaar doek in jute.',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBoomspiegelInvulling/biologisch-afbreekbaar-doek-jute'),
        'boomschors': KeuzelijstWaarde(invulwaarde='boomschors',
                                       label='boomschors',
                                       status='ingebruik',
                                       definitie='Afdekking van de bodem rond de boom met boomschors.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBoomspiegelInvulling/boomschors'),
        'gras': KeuzelijstWaarde(invulwaarde='gras',
                                 label='gras',
                                 status='ingebruik',
                                 definitie='De boomspiegel bestaat voornamelijk uit grazige vegetatie die gemaaid kan worden',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBoomspiegelInvulling/gras'),
        'groencompost': KeuzelijstWaarde(invulwaarde='groencompost',
                                         label='groencompost',
                                         status='ingebruik',
                                         definitie='Afdekking van de bodem rond de boom met groencompost.',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBoomspiegelInvulling/groencompost'),
        'houtsnippers': KeuzelijstWaarde(invulwaarde='houtsnippers',
                                         label='houtsnippers',
                                         status='ingebruik',
                                         definitie='Afdekking van de bodem rond de boom met houtsnippers.',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBoomspiegelInvulling/houtsnippers'),
        'kaal': KeuzelijstWaarde(invulwaarde='kaal',
                                 label='kaal',
                                 status='ingebruik',
                                 definitie='De boomspiegel is kaal of licht begroeid met onkruid (<25%) en word niet gemaaid',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBoomspiegelInvulling/kaal'),
        'minerale-mulch': KeuzelijstWaarde(invulwaarde='minerale-mulch',
                                           label='minerale mulch',
                                           status='ingebruik',
                                           definitie='De boomspiegel bestaat uit een bodembedekking van minerale oorsprong (vb. grind, dolomiet)',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBoomspiegelInvulling/minerale-mulch'),
        'organische-mulch': KeuzelijstWaarde(invulwaarde='organische-mulch',
                                             label='organische mulch',
                                             status='ingebruik',
                                             definitie='Afdekking van de bodem rond de boom met organische mulch.',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBoomspiegelInvulling/organische-mulch'),
        'rooster': KeuzelijstWaarde(invulwaarde='rooster',
                                    label='rooster',
                                    status='ingebruik',
                                    definitie='De boomspiegel is een rooster',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBoomspiegelInvulling/rooster'),
        'verharding': KeuzelijstWaarde(invulwaarde='verharding',
                                       label='verharding',
                                       status='ingebruik',
                                       definitie='In de boomspiegel is verharding aanwezig tot op minder dan 30cm van de stamvoet',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBoomspiegelInvulling/verharding')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from abc import abstractmethod
from otlmow_model.Datatypes.KwantWrdInKiloNewton import KwantWrdInKiloNewton, KwantWrdInKiloNewtonWaarden
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class AxiaalDraagvermogen(PuntGeometrie):
    """Abstracte voor de bundeling van de axiale druk- en trekdraagvermogens, berekend volgens verschillende grenstoestanden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AxiaalDraagvermogen'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self._drukdraagvermogenGGT = OTLAttribuut(field=KwantWrdInKiloNewton,
                                                  naam='drukdraagvermogenGGT',
                                                  label='drukdraagvermogen in gebruiksgrenstoestanden',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AxiaalDraagvermogen.drukdraagvermogenGGT',
                                                  definition='Karakteristieke waarde van de maximale druklast die een constructie-element kan dragen in gebruiksgrenstoestanden (GGT), uitgedrukt in kilonewton.',
                                                  owner=self)

        self._drukdraagvermogenUGT = OTLAttribuut(field=KwantWrdInKiloNewton,
                                                  naam='drukdraagvermogenUGT',
                                                  label='drukdraagvermogen in uiterste grenstoestand',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AxiaalDraagvermogen.drukdraagvermogenUGT',
                                                  definition='Drukdraagvermogen, uitgedrukt in kilonewton, in uiterste grenstoestand (UGT) design approach DA1/1.',
                                                  owner=self)

        self._trekdraagvermorgenGGT = OTLAttribuut(field=KwantWrdInKiloNewton,
                                                   naam='trekdraagvermorgenGGT',
                                                   label='trekdraagvermogen in gebruiksgrenstoestanden',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AxiaalDraagvermogen.trekdraagvermorgenGGT',
                                                   definition='Karakteristieke waarde van de maximale treklast die een constructie-element kan dragen in gebruiksgrenstoestanden (GGT), uitgedrukt in kilonewton.',
                                                   owner=self)

        self._trekdraagvermorgenUGT = OTLAttribuut(field=KwantWrdInKiloNewton,
                                                   naam='trekdraagvermorgenUGT',
                                                   label='trekdraagvermogen in uiterste grenstoestand',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AxiaalDraagvermogen.trekdraagvermorgenUGT',
                                                   definition='Trekdraagvermogen, uitgedrukt in kilonewton, in uiterste grenstoestand (UGT) design approach DA1/1.',
                                                   owner=self)

    @property
    def drukdraagvermogenGGT(self) -> KwantWrdInKiloNewtonWaarden:
        """Karakteristieke waarde van de maximale druklast die een constructie-element kan dragen in gebruiksgrenstoestanden (GGT), uitgedrukt in kilonewton."""
        return self._drukdraagvermogenGGT.get_waarde()

    @drukdraagvermogenGGT.setter
    def drukdraagvermogenGGT(self, value):
        self._drukdraagvermogenGGT.set_waarde(value, owner=self)

    @property
    def drukdraagvermogenUGT(self) -> KwantWrdInKiloNewtonWaarden:
        """Drukdraagvermogen, uitgedrukt in kilonewton, in uiterste grenstoestand (UGT) design approach DA1/1."""
        return self._drukdraagvermogenUGT.get_waarde()

    @drukdraagvermogenUGT.setter
    def drukdraagvermogenUGT(self, value):
        self._drukdraagvermogenUGT.set_waarde(value, owner=self)

    @property
    def trekdraagvermorgenGGT(self) -> KwantWrdInKiloNewtonWaarden:
        """Karakteristieke waarde van de maximale treklast die een constructie-element kan dragen in gebruiksgrenstoestanden (GGT), uitgedrukt in kilonewton."""
        return self._trekdraagvermorgenGGT.get_waarde()

    @trekdraagvermorgenGGT.setter
    def trekdraagvermorgenGGT(self, value):
        self._trekdraagvermorgenGGT.set_waarde(value, owner=self)

    @property
    def trekdraagvermorgenUGT(self) -> KwantWrdInKiloNewtonWaarden:
        """Trekdraagvermogen, uitgedrukt in kilonewton, in uiterste grenstoestand (UGT) design approach DA1/1."""
        return self._trekdraagvermorgenUGT.get_waarde()

    @trekdraagvermorgenUGT.setter
    def trekdraagvermorgenUGT(self, value):
        self._trekdraagvermorgenUGT.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBetonmilieuklasse(KeuzelijstField):
    """Milieuklasse (X-klasse) waaraan het beton wordt blootgesteld."""
    naam = 'KlBetonmilieuklasse'
    label = 'Betonmilieuklasse'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlBetonmilieuklasse'
    definition = 'Milieuklasse (X-klasse) waaraan het beton wordt blootgesteld.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBetonmilieuklasse'
    options = {
        'x-0': KeuzelijstWaarde(invulwaarde='x-0',
                                label='X0',
                                status='ingebruik',
                                definitie='Geen risico op corrosie of aantasting, voor beton zonder wapening of ingesloten metalen, behalve bij vorst, dooi of chemische aantasting.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-0'),
        'x-a-1': KeuzelijstWaarde(invulwaarde='x-a-1',
                                  label='XA1',
                                  status='ingebruik',
                                  definitie='Chemische aantasting (Aggressive) : zwak agressieve omgeving.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-a-1'),
        'x-a-2': KeuzelijstWaarde(invulwaarde='x-a-2',
                                  label='XA2',
                                  status='ingebruik',
                                  definitie='Chemische aantasting (Aggressive) : matig agressieve omgeving.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-a-2'),
        'x-a-3': KeuzelijstWaarde(invulwaarde='x-a-3',
                                  label='XA3',
                                  status='ingebruik',
                                  definitie='Chemische aantasting (Aggressive) : sterk agressieve omgeving.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-a-3'),
        'x-c-1': KeuzelijstWaarde(invulwaarde='x-c-1',
                                  label='XC1',
                                  status='ingebruik',
                                  definitie='Corrosie ingeleid door carbonatatie (Carbonatation) : droge of blijvend natte omgeving.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-c-1'),
        'x-c-2': KeuzelijstWaarde(invulwaarde='x-c-2',
                                  label='XC2',
                                  status='ingebruik',
                                  definitie='Corrosie ingeleid door carbonatatie (Carbonatation) : natte omgeving die zelden droog is.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-c-2'),
        'x-c-3': KeuzelijstWaarde(invulwaarde='x-c-3',
                                  label='XC3',
                                  status='ingebruik',
                                  definitie='Corrosie ingeleid door carbonatatie (Carbonatation) : omgeving met matige vochtigheid.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-c-3'),
        'x-c-4': KeuzelijstWaarde(invulwaarde='x-c-4',
                                  label='XC4',
                                  status='ingebruik',
                                  definitie='Corrosie ingeleid door carbonatatie (Carbonatation) : wisselend natte en droge omgeving.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-c-4'),
        'x-d-1': KeuzelijstWaarde(invulwaarde='x-d-1',
                                  label='XD1',
                                  status='ingebruik',
                                  definitie='Corrosie ingeleid door chloriden anders dan afkomstig uit zeewater (dooizouten, De-icing salts) : omgeving met matige vochtigheid.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-d-1'),
        'x-d-2': KeuzelijstWaarde(invulwaarde='x-d-2',
                                  label='XD2',
                                  status='ingebruik',
                                  definitie='Corrosie ingeleid door chloriden anders dan afkomstig uit zeewater (dooizouten, De-icing salts) : natte omgeving die zelden droog is.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-d-2'),
        'x-d-3': KeuzelijstWaarde(invulwaarde='x-d-3',
                                  label='XD3',
                                  status='ingebruik',
                                  definitie='Corrosie ingeleid door chloriden anders dan afkomstig uit zeewater (dooizouten, De-icing salts) : wisselend natte en droge omgeving.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-d-3'),
        'x-f-1': KeuzelijstWaarde(invulwaarde='x-f-1',
                                  label='XF1',
                                  status='ingebruik',
                                  definitie='Aantasting door vorst-/dooi-wisseling met of zonder dooizouten (Frost) : omgeving niet-volledig verzadigd met water, zonder dooizouten.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-f-1'),
        'x-f-2': KeuzelijstWaarde(invulwaarde='x-f-2',
                                  label='XF2',
                                  status='ingebruik',
                                  definitie='Aantasting door vorst-/dooi-wisseling met of zonder dooizouten (Frost) : omgeving niet-volledig verzadigd met water, met dooizouten.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-f-2'),
        'x-f-3': KeuzelijstWaarde(invulwaarde='x-f-3',
                                  label='XF3',
                                  status='ingebruik',
                                  definitie='Aantasting door vorst-/dooi-wisseling met of zonder dooizouten (Frost) : omgeving verzadigd met water, zonder dooizouten.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-f-3'),
        'x-f-4': KeuzelijstWaarde(invulwaarde='x-f-4',
                                  label='XF4',
                                  status='ingebruik',
                                  definitie='Aantasting door vorst-/dooi-wisseling met of zonder dooizouten (Frost) : omgeving verzadigd met water, met dooizouten.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-f-4'),
        'x-s-1': KeuzelijstWaarde(invulwaarde='x-s-1',
                                  label='XS1',
                                  status='ingebruik',
                                  definitie='Corrosie ingeleid door chloriden (zeewater, Seawater) : omgeving met zouthoudende lucht.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-s-1'),
        'x-s-2': KeuzelijstWaarde(invulwaarde='x-s-2',
                                  label='XS2',
                                  status='ingebruik',
                                  definitie='Corrosie ingeleid door chloriden (zeewater, Seawater) : blijvend onder zeewater.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-s-2'),
        'x-s-3': KeuzelijstWaarde(invulwaarde='x-s-3',
                                  label='XS3',
                                  status='ingebruik',
                                  definitie='Corrosie ingeleid door chloriden (zeewater, Seawater) : getijde-, spat- en stuifzone.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBetonmilieuklasse/x-s-3')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.Datatypes.KlAlgMateriaal import KlAlgMateriaal
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Weegplaat(AIMObject, VlakGeometrie):
    """Een plaat waarop te wegen objecten komen en die rust op weegsensoren rust."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Weegplaat'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMObject.__init__(self)
        VlakGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Aswegersite')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Weegcel')

        self._materiaal = OTLAttribuut(field=KlAlgMateriaal,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Weegplaat.materiaal',
                                       definition='Het materiaal waaruit de weegplaat is gemaakt volgens een vaste lijst van mogelijke materialen.',
                                       owner=self)

    @property
    def materiaal(self) -> str:
        """Het materiaal waaruit de weegplaat is gemaakt volgens een vaste lijst van mogelijke materialen."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)



# coding=utf-8
from typing import List
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.BegroeidVoorkomen import BegroeidVoorkomen
from otlmow_model.Datatypes.DtcSierbeplAanleg import DtcSierbeplAanleg, DtcSierbeplAanlegWaarden
from otlmow_model.Datatypes.KlSierbeplantingType import KlSierbeplantingType
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Sierbeplanting(BegroeidVoorkomen, VlakGeometrie):
    """Planten die geen blijvende houtige stengel vormen. Eenjarige,tweejarige of vaste planten,die in de winter tot de grond toe afsterven."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sierbeplanting'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        BegroeidVoorkomen.__init__(self)
        VlakGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HeeftBeheer', target='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#BeheerSierbeplanting')

        self._aanleg = OTLAttribuut(field=DtcSierbeplAanleg,
                                    naam='aanleg',
                                    label='aanleg',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sierbeplanting.aanleg',
                                    definition='De manier van aanplanten van de sierbeplanting.',
                                    owner=self)

        self._type = OTLAttribuut(field=KlSierbeplantingType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sierbeplanting.type',
                                  kardinaliteit_max='*',
                                  definition='Type van sierbeplanting.',
                                  owner=self)

    @property
    def aanleg(self) -> DtcSierbeplAanlegWaarden:
        """De manier van aanplanten van de sierbeplanting."""
        return self._aanleg.get_waarde()

    @aanleg.setter
    def aanleg(self, value):
        self._aanleg.set_waarde(value, owner=self)

    @property
    def type(self) -> List[str]:
        """Type van sierbeplanting."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from typing import List
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.HoutigeVegetatie import HoutigeVegetatie
from otlmow_model.Datatypes.KlGroeiplaatsverbetering import KlGroeiplaatsverbetering
from otlmow_model.Datatypes.KlHoutigeType import KlHoutigeType
from otlmow_model.Datatypes.KlNSB import KlNSB
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class OpgaandeHoutigeVegetatie(HoutigeVegetatie, VlakGeometrie):
    """Een houtkant of een bos."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#OpgaandeHoutigeVegetatie'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        HoutigeVegetatie.__init__(self)
        VlakGeometrie.__init__(self)

        self._groeiplaatsverbetering = OTLAttribuut(field=KlGroeiplaatsverbetering,
                                                    naam='groeiplaatsverbetering',
                                                    label='groeiplaatsverbetering',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#OpgaandeHoutigeVegetatie.groeiplaatsverbetering',
                                                    kardinaliteit_max='*',
                                                    definition='De techniek waarmee de groeiplaats wordt verbeterd met als doel de levensverwachting en de conditie van de vegetatie te verbeteren.',
                                                    owner=self)

        self._huidigNatuurbeeld = OTLAttribuut(field=KlNSB,
                                               naam='huidigNatuurbeeld',
                                               label='huidig natuurbeeld',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#OpgaandeHoutigeVegetatie.huidigNatuurbeeld',
                                               definition='Bepaling van het vegetatietype op basis van terreininventarisatie.',
                                               owner=self)

        self._natuurstreefbeeld = OTLAttribuut(field=KlNSB,
                                               naam='natuurstreefbeeld',
                                               label='natuurstreefbeeld',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#OpgaandeHoutigeVegetatie.natuurstreefbeeld',
                                               definition='Een natuurstreefbeeld is een nagestreefd biotoop, mozaïek van biotopen of een leefgebied van een soort dat je wil behouden of verkrijgen via een goed natuurbeheer. In het definitief plan van type twee, drie of vier wordt het ecologisch einddoel vastgesteld aan de hand van natuurstreefbeelden.',
                                               owner=self)

        self._type = OTLAttribuut(field=KlHoutigeType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#OpgaandeHoutigeVegetatie.type',
                                  definition='Het type van de opgaande houtige vegetatie.',
                                  owner=self)

    @property
    def groeiplaatsverbetering(self) -> List[str]:
        """De techniek waarmee de groeiplaats wordt verbeterd met als doel de levensverwachting en de conditie van de vegetatie te verbeteren."""
        return self._groeiplaatsverbetering.get_waarde()

    @groeiplaatsverbetering.setter
    def groeiplaatsverbetering(self, value):
        self._groeiplaatsverbetering.set_waarde(value, owner=self)

    @property
    def huidigNatuurbeeld(self) -> str:
        """Bepaling van het vegetatietype op basis van terreininventarisatie."""
        return self._huidigNatuurbeeld.get_waarde()

    @huidigNatuurbeeld.setter
    def huidigNatuurbeeld(self, value):
        self._huidigNatuurbeeld.set_waarde(value, owner=self)

    @property
    def natuurstreefbeeld(self) -> str:
        """Een natuurstreefbeeld is een nagestreefd biotoop, mozaïek van biotopen of een leefgebied van een soort dat je wil behouden of verkrijgen via een goed natuurbeheer. In het definitief plan van type twee, drie of vier wordt het ecologisch einddoel vastgesteld aan de hand van natuurstreefbeelden."""
        return self._natuurstreefbeeld.get_waarde()

    @natuurstreefbeeld.setter
    def natuurstreefbeeld(self, value):
        self._natuurstreefbeeld.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Het type van de opgaande houtige vegetatie."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLETrottoirbandWatergreppelType(KeuzelijstField):
    """De vormen van een trottoirband_watergreppel."""
    naam = 'KlLETrottoirbandWatergreppelType'
    label = 'Trottoirband watergreppel type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLETrottoirbandWatergreppelType'
    definition = 'De vormen van een trottoirband_watergreppel.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLETrottoirbandWatergreppelType'
    options = {
        'type-III-A': KeuzelijstWaarde(invulwaarde='type-III-A',
                                       label='type III A',
                                       status='ingebruik',
                                       definitie='type III A',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandWatergreppelType/type-III-A'),
        'type-III-B': KeuzelijstWaarde(invulwaarde='type-III-B',
                                       label='type III B',
                                       status='ingebruik',
                                       definitie='type III B',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandWatergreppelType/type-III-B'),
        'type-III-C': KeuzelijstWaarde(invulwaarde='type-III-C',
                                       label='type III C',
                                       status='ingebruik',
                                       definitie='type III C',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandWatergreppelType/type-III-C'),
        'type-III-D': KeuzelijstWaarde(invulwaarde='type-III-D',
                                       label='type III D',
                                       status='ingebruik',
                                       definitie='type III D',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandWatergreppelType/type-III-D'),
        'type-III-E': KeuzelijstWaarde(invulwaarde='type-III-E',
                                       label='type III E',
                                       status='ingebruik',
                                       definitie='type III E',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLETrottoirbandWatergreppelType/type-III-E')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.KwantWrdInAmpere import KwantWrdInAmpere, KwantWrdInAmpereWaarden
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Laagspanningsbord(AIMNaamObject, PuntGeometrie):
    """Verzameling van alle elektrische componenten nodig voor de voeding en sturing van applicaties die erop aangesloten zijn. Omvat onder andere automaten,klemmenblokken,..."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Laagspanningsbord'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMNaamObject.__init__(self)
        PuntGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Behuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#DNBMeter')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aftakking')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cabinecontroller')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Contactor')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#EnergiemeterDerden')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hoofdschakelaar')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Segmentcontroller')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Veiligheidsrelais')

        self._elektrischSchema = OTLAttribuut(field=DtcDocument,
                                              naam='elektrischSchema',
                                              label='elektrisch schema',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Laagspanningsbord.elektrischSchema',
                                              usagenote='Bestanden van het type pdf,dwg of dxf.',
                                              definition='Het elektrisch aansluitschema van het laagspanningsbord.',
                                              owner=self)

        self._vermogen = OTLAttribuut(field=KwantWrdInAmpere,
                                      naam='vermogen',
                                      label='vermogen',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Laagspanningsbord.vermogen',
                                      definition='Het vermogen van het laagspanningsbord.',
                                      owner=self)

    @property
    def elektrischSchema(self) -> DtcDocumentWaarden:
        """Het elektrisch aansluitschema van het laagspanningsbord."""
        return self._elektrischSchema.get_waarde()

    @elektrischSchema.setter
    def elektrischSchema(self, value):
        self._elektrischSchema.set_waarde(value, owner=self)

    @property
    def vermogen(self) -> KwantWrdInAmpereWaarden:
        """Het vermogen van het laagspanningsbord."""
        return self._vermogen.get_waarde()

    @vermogen.setter
    def vermogen(self, value):
        self._vermogen.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlFiguratieSoortVerschuind(KeuzelijstField):
    """Soorten van verschuinde figuratie markering."""
    naam = 'KlFiguratieSoortVerschuind'
    label = 'Figuratie soort verschuind'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlFiguratieSoortVerschuind'
    definition = 'Soorten van verschuinde figuratie markering.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlFiguratieSoortVerschuind'
    options = {
        'letterfiguratiemarkering(schuin)': KeuzelijstWaarde(invulwaarde='letterfiguratiemarkering(schuin)',
                                                             label='letterfiguratiemarkering(schuin)',
                                                             status='ingebruik',
                                                             definitie='Een schuine lettermarking als figuratie zoals BUS, TAXI, TRAM,....',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieSoortVerschuind/letterfiguratiemarkering(schuin)'),
        'omgekeerde-driehoek(schuin)': KeuzelijstWaarde(invulwaarde='omgekeerde-driehoek(schuin)',
                                                        label='omgekeerde driehoek(schuin)',
                                                        status='ingebruik',
                                                        definitie='Een schuine omgekeerde driehoek markering.',
                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieSoortVerschuind/omgekeerde-driehoek(schuin)')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlGraadVanStatischeBepaaldheid(KeuzelijstField):
    """De statische bepaaldheid van het brugdeel."""
    naam = 'KlGraadVanStatischeBepaaldheid'
    label = 'Graad van statische bepaaldheid'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlGraadVanStatischeBepaaldheid'
    definition = 'De statische bepaaldheid van het brugdeel.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlGraadVanStatischeBepaaldheid'
    options = {
        'hyperstatisch': KeuzelijstWaarde(invulwaarde='hyperstatisch',
                                          label='Hyperstatisch',
                                          status='ingebruik',
                                          definitie='Statisch onbepaald. De reacties (de momenten en dwarskrachten) kunnen niet worden berekend met de statica alleen.',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlGraadVanStatischeBepaaldheid/hyperstatisch'),
        'isostatisch': KeuzelijstWaarde(invulwaarde='isostatisch',
                                        label='Isostatisch',
                                        status='ingebruik',
                                        definitie='Statisch bepaald. De reacties en inwendige krachten zijn te berekenen met de statica.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlGraadVanStatischeBepaaldheid/isostatisch')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.Proef import Proef
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie
from otlmow_model.GeometrieTypes.LijnGeometrie import LijnGeometrie
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class ProefRolgeluid(Proef, PuntGeometrie, LijnGeometrie, VlakGeometrie):
    """Het rolgeluid wordt gemeten met de CPX-methode volgens ISO/CEN 11819-2."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefRolgeluid'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        Proef.__init__(self)
        LijnGeometrie.__init__(self)
        PuntGeometrie.__init__(self)
        VlakGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BitumineuzeLaag')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cementbetonverharding')

        self._rolgeluid = OTLAttribuut(field=DtcDocument,
                                       naam='rolgeluid',
                                       label='rolgeluid',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefRolgeluid.rolgeluid',
                                       definition='Proefresultaten van het rolgeluid van de toplaag.',
                                       owner=self)

    @property
    def rolgeluid(self) -> DtcDocumentWaarden:
        """Proefresultaten van het rolgeluid van de toplaag."""
        return self._rolgeluid.get_waarde()

    @rolgeluid.setter
    def rolgeluid(self, value):
        self._rolgeluid.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from abc import abstractmethod, ABC
from otlmow_model.BaseClasses.BooleanField import BooleanField
from otlmow_model.BaseClasses.StringField import StringField


# Generated with OTLClassCreator. To modify: extend, do not edit
class AOWSType(ABC):
    """Abstracte om alle eigenschappen en relaties van AOWS type onder 1 noemer te houden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AOWSType'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        self._isGoedgekeurd = OTLAttribuut(field=BooleanField,
                                           naam='isGoedgekeurd',
                                           label='is goedgekeurd',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AOWSType.isGoedgekeurd',
                                           definition='Bepaling van de goedkeuring van AOWS.',
                                           owner=self)

        self._versieGoedgekeurd = OTLAttribuut(field=StringField,
                                               naam='versieGoedgekeurd',
                                               label='versie goedgekeurd',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AOWSType.versieGoedgekeurd',
                                               definition='De versie van het standaardbestek 250 waar de goedkeuring is bepaald.',
                                               owner=self)

    @property
    def isGoedgekeurd(self) -> bool:
        """Bepaling van de goedkeuring van AOWS."""
        return self._isGoedgekeurd.get_waarde()

    @isGoedgekeurd.setter
    def isGoedgekeurd(self, value):
        self._isGoedgekeurd.set_waarde(value, owner=self)

    @property
    def versieGoedgekeurd(self) -> str:
        """De versie van het standaardbestek 250 waar de goedkeuring is bepaald."""
        return self._versieGoedgekeurd.get_waarde()

    @versieGoedgekeurd.setter
    def versieGoedgekeurd(self, value):
        self._versieGoedgekeurd.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTelecomkabelAdersEnSectie(KeuzelijstField):
    """Lijst van mogelijke waarden volgens de catalogusposten van het standaardbestek voor de samenstelling van een telecomkabel volgens het aantal aders en hun dikte in vierkante millimeter."""
    naam = 'KlTelecomkabelAdersEnSectie'
    label = 'Telecomkabel aders en sectie'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlTelecomkabelAdersEnSectie'
    definition = 'Lijst van mogelijke waarden volgens de catalogusposten van het standaardbestek voor de samenstelling van een telecomkabel volgens het aantal aders en hun dikte in vierkante millimeter.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTelecomkabelAdersEnSectie'
    options = {
        '100-x-2-x-1-mm2': KeuzelijstWaarde(invulwaarde='100-x-2-x-1-mm2',
                                            label='100 x 2 X 1 mm²',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/100-x-2-x-1-mm2'),
        '10x4x1': KeuzelijstWaarde(invulwaarde='10x4x1',
                                   label='10x4x1',
                                   status='ingebruik',
                                   definitie='10x4x1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/10x4x1'),
        '12': KeuzelijstWaarde(invulwaarde='12',
                               label='12',
                               status='ingebruik',
                               definitie='12',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/12'),
        '20-x-2-x-1-mm2': KeuzelijstWaarde(invulwaarde='20-x-2-x-1-mm2',
                                           label='20 x 2 X 1 mm²',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/20-x-2-x-1-mm2'),
        '20x4x1': KeuzelijstWaarde(invulwaarde='20x4x1',
                                   label='20x4x1',
                                   status='ingebruik',
                                   definitie='20x4x1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/20x4x1'),
        '21-x-2-x-1-mm2': KeuzelijstWaarde(invulwaarde='21-x-2-x-1-mm2',
                                           label='21 x 2 X 1 mm²',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/21-x-2-x-1-mm2'),
        '24': KeuzelijstWaarde(invulwaarde='24',
                               label='24',
                               status='ingebruik',
                               definitie='24',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/24'),
        '25x4x1': KeuzelijstWaarde(invulwaarde='25x4x1',
                                   label='25x4x1',
                                   status='ingebruik',
                                   definitie='25x4x1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/25x4x1'),
        '30x4x1': KeuzelijstWaarde(invulwaarde='30x4x1',
                                   label='30x4x1',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/30x4x1'),
        '32x4x1': KeuzelijstWaarde(invulwaarde='32x4x1',
                                   label='32x4x1',
                                   status='ingebruik',
                                   definitie='32x4x1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/32x4x1'),
        '34x4x1': KeuzelijstWaarde(invulwaarde='34x4x1',
                                   label='34x4x1',
                                   status='ingebruik',
                                   definitie='34x4x1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/34x4x1'),
        '4': KeuzelijstWaarde(invulwaarde='4',
                              label='4',
                              status='ingebruik',
                              definitie='4',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/4'),
        '40x4x1': KeuzelijstWaarde(invulwaarde='40x4x1',
                                   label='40x4x1',
                                   status='ingebruik',
                                   definitie='40x4x1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/40x4x1'),
        '48': KeuzelijstWaarde(invulwaarde='48',
                               label='48',
                               status='ingebruik',
                               definitie='48',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/48'),
        '48-vezels': KeuzelijstWaarde(invulwaarde='48-vezels',
                                      label='48 vezels',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/48-vezels'),
        '50x4x1': KeuzelijstWaarde(invulwaarde='50x4x1',
                                   label='50x4x1',
                                   status='ingebruik',
                                   definitie='50x4x1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/50x4x1'),
        '5x4x1': KeuzelijstWaarde(invulwaarde='5x4x1',
                                  label='5x4x1',
                                  status='ingebruik',
                                  definitie='5x4x1',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/5x4x1'),
        '7x1.5': KeuzelijstWaarde(invulwaarde='7x1.5',
                                  label='7x1.5',
                                  status='ingebruik',
                                  definitie='7x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/7x1.5'),
        '7x2x0.8': KeuzelijstWaarde(invulwaarde='7x2x0.8',
                                    label='7x2x0.8',
                                    status='ingebruik',
                                    definitie='7x2x0.8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/7x2x0.8'),
        '8': KeuzelijstWaarde(invulwaarde='8',
                              label='8',
                              status='ingebruik',
                              definitie='8',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/8'),
        '96-vezels': KeuzelijstWaarde(invulwaarde='96-vezels',
                                      label='96 vezels',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/96-vezels'),
        'onbekend': KeuzelijstWaarde(invulwaarde='onbekend',
                                     label='onbekend',
                                     status='ingebruik',
                                     definitie='onbekend',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/onbekend'),
        'zonder-verdere-specificatie': KeuzelijstWaarde(invulwaarde='zonder-verdere-specificatie',
                                                        label='zonder verdere specificatie',
                                                        status='ingebruik',
                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/zonder-verdere-specificatie')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.BaseClasses.ComplexField import ComplexField
from otlmow_model.Datatypes.KlZelfsluiterSluitkrachtnorm import KlZelfsluiterSluitkrachtnorm


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcZelfsluiterSluitkrachtWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._bovengrens = OTLAttribuut(field=KlZelfsluiterSluitkrachtnorm,
                                        naam='bovengrens',
                                        label='bovengrens',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcZelfsluiterSluitkracht.bovengrens',
                                        usagenote='Gebruik dezelfde waarde voor onder- en bovengrens en ingestelde sluitkracht voor zelfsluiters zonder bereik, met slechts een mogelijke invulling van de sluitkracht.',
                                        definition='Hoogste sluitkracht van de zelfsluiter voor deuren, poorten etc. volgens de bestaande normering',
                                        owner=self)

        self._ingesteld = OTLAttribuut(field=KlZelfsluiterSluitkrachtnorm,
                                       naam='ingesteld',
                                       label='ingesteld',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcZelfsluiterSluitkracht.ingesteld',
                                       usagenote='Gebruik dezelfde waarde voor onder- en bovengrens en ingestelde sluitkracht voor zelfsluiters zonder bereik, met slechts een mogelijke invulling van de sluitkracht.',
                                       definition='De ingestelde sluitkracht van de zelfsluiter voor deuren, poorten etc. volgens de bestaande normering',
                                       owner=self)

        self._ondergrens = OTLAttribuut(field=KlZelfsluiterSluitkrachtnorm,
                                        naam='ondergrens',
                                        label='ondergrens',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcZelfsluiterSluitkracht.ondergrens',
                                        usagenote='Gebruik dezelfde waarde voor onder- en bovengrens en ingestelde sluitkracht voor zelfsluiters zonder bereik, met slechts een mogelijke invulling van de sluitkracht.',
                                        definition='Laagste sluitkracht van de zelfsluiter voor deuren, poorten etc. volgens de bestaande normering',
                                        owner=self)

    @property
    def bovengrens(self) -> str:
        """Hoogste sluitkracht van de zelfsluiter voor deuren, poorten etc. volgens de bestaande normering"""
        return self._bovengrens.get_waarde()

    @bovengrens.setter
    def bovengrens(self, value):
        self._bovengrens.set_waarde(value, owner=self._parent)

    @property
    def ingesteld(self) -> str:
        """De ingestelde sluitkracht van de zelfsluiter voor deuren, poorten etc. volgens de bestaande normering"""
        return self._ingesteld.get_waarde()

    @ingesteld.setter
    def ingesteld(self, value):
        self._ingesteld.set_waarde(value, owner=self._parent)

    @property
    def ondergrens(self) -> str:
        """Laagste sluitkracht van de zelfsluiter voor deuren, poorten etc. volgens de bestaande normering"""
        return self._ondergrens.get_waarde()

    @ondergrens.setter
    def ondergrens(self, value):
        self._ondergrens.set_waarde(value, owner=self._parent)


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcZelfsluiterSluitkracht(ComplexField):
    """Datatype voor het bereik en de instelling van een zelfsluiter voor deuren, poorten etc."""
    naam = 'DtcZelfsluiterSluitkracht'
    label = 'Zelfsluiter sluitkracht'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcZelfsluiterSluitkracht'
    definition = 'Datatype voor het bereik en de instelling van een zelfsluiter voor deuren, poorten etc.'
    waardeObject = DtcZelfsluiterSluitkrachtWaarden

    def __str__(self):
        return ComplexField.__str__(self)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.Niveaumeting import Niveaumeting
from otlmow_model.Datatypes.KlHydrostatischeNiveaumetingMerk import KlHydrostatischeNiveaumetingMerk
from otlmow_model.Datatypes.KlHydrostatischeNiveaumetingModelnaam import KlHydrostatischeNiveaumetingModelnaam


# Generated with OTLClassCreator. To modify: extend, do not edit
class HydrostatischeNiveaumeting(Niveaumeting):
    """Een inrichting voor het bepalen van het peil van een vloeistof (bv. het waterniveau in een vloeistoftank of lekwaterput van een kelder). De sensor meet de hydrostatische druk (gewicht) van een vloeistof en bepaalt met deze gegevens het niveau van de vloeistof. Het resultaat wordt omgezet in een uitleesbaar signaal.
"""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HydrostatischeNiveaumeting'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._merk = OTLAttribuut(field=KlHydrostatischeNiveaumetingMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HydrostatischeNiveaumeting.merk',
                                  definition='Het merk van de hydrostatische niveaumeting.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlHydrostatischeNiveaumetingModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HydrostatischeNiveaumeting.modelnaam',
                                       definition='De modelnaam van de hydrostatische niveaumeting.',
                                       owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de hydrostatische niveaumeting."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de hydrostatische niveaumeting."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlCBVOppervlaktebehandeling(KeuzelijstField):
    """Oppervalktebehandelingen van de cement/beton verharding."""
    naam = 'KlCBVOppervlaktebehandeling'
    label = 'CBV oppervlaktebehandeling'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlCBVOppervlaktebehandeling'
    definition = 'Oppervalktebehandelingen van de cement/beton verharding.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlCBVOppervlaktebehandeling'
    options = {
        'Reinigen-met-water-onder-hoge-druk-(minstens-50-bar)-': KeuzelijstWaarde(invulwaarde='Reinigen-met-water-onder-hoge-druk-(minstens-50-bar)-',
                                                                                  label='Reinigen met water onder hoge druk (minstens 50 bar) ',
                                                                                  status='ingebruik',
                                                                                  definitie='Reinigen met water onder hoge druk (minstens 50 bar) ',
                                                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCBVOppervlaktebehandeling/Reinigen-met-water-onder-hoge-druk-(minstens-50-bar)-'),
        'bezemen': KeuzelijstWaarde(invulwaarde='bezemen',
                                    label='bezemen',
                                    status='ingebruik',
                                    definitie='Bezemen',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCBVOppervlaktebehandeling/bezemen'),
        'eenvoudig-dwars-bezemen': KeuzelijstWaarde(invulwaarde='eenvoudig-dwars-bezemen',
                                                    label='eenvoudig dwars bezemen',
                                                    status='ingebruik',
                                                    definitie='Eenvoudig dwars bezemen',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCBVOppervlaktebehandeling/eenvoudig-dwars-bezemen'),
        'eenvoudig-langs-bezemen': KeuzelijstWaarde(invulwaarde='eenvoudig-langs-bezemen',
                                                    label='eenvoudig langs bezemen',
                                                    status='ingebruik',
                                                    definitie='Eenvoudig langs bezemen',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCBVOppervlaktebehandeling/eenvoudig-langs-bezemen'),
        'figureren': KeuzelijstWaarde(invulwaarde='figureren',
                                      label='figureren',
                                      status='ingebruik',
                                      definitie='Figureren',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCBVOppervlaktebehandeling/figureren'),
        'uitwassen-van-het-steenslagskelet': KeuzelijstWaarde(invulwaarde='uitwassen-van-het-steenslagskelet',
                                                              label='uitwassen van het steenslagskelet',
                                                              status='ingebruik',
                                                              definitie='Uitwassen van het steenslagskelet',
                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCBVOppervlaktebehandeling/uitwassen-van-het-steenslagskelet')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlWvLedTussenafstand(KeuzelijstField):
    """Afstand tussen de verschillende LED verlichtingstoestellen."""
    naam = 'KlWvLedTussenafstand'
    label = 'WV LED tussenafstand'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlWvLedTussenafstand'
    definition = 'Afstand tussen de verschillende LED verlichtingstoestellen.'
    status = 'ingebruik'
    deprecated_version = '2.4.0'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlWvLedTussenafstand'
    options = {
        'S015': KeuzelijstWaarde(invulwaarde='S015',
                                 label='S015',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedTussenafstand/S015'),
        'S020': KeuzelijstWaarde(invulwaarde='S020',
                                 label='S020',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedTussenafstand/S020'),
        'S025': KeuzelijstWaarde(invulwaarde='S025',
                                 label='S025',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedTussenafstand/S025'),
        'S030': KeuzelijstWaarde(invulwaarde='S030',
                                 label='S030',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedTussenafstand/S030'),
        'S035': KeuzelijstWaarde(invulwaarde='S035',
                                 label='S035',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedTussenafstand/S035'),
        'S040': KeuzelijstWaarde(invulwaarde='S040',
                                 label='S040',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedTussenafstand/S040'),
        'S045': KeuzelijstWaarde(invulwaarde='S045',
                                 label='S045',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedTussenafstand/S045'),
        'S050': KeuzelijstWaarde(invulwaarde='S050',
                                 label='S050',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedTussenafstand/S050'),
        'S060': KeuzelijstWaarde(invulwaarde='S060',
                                 label='S060',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedTussenafstand/S060'),
        'S070': KeuzelijstWaarde(invulwaarde='S070',
                                 label='S070',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedTussenafstand/S070'),
        'S080': KeuzelijstWaarde(invulwaarde='S080',
                                 label='S080',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedTussenafstand/S080'),
        'S090': KeuzelijstWaarde(invulwaarde='S090',
                                 label='S090',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedTussenafstand/S090'),
        'S100': KeuzelijstWaarde(invulwaarde='S100',
                                 label='S100',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedTussenafstand/S100')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.IPNetwerkToegangObject import IPNetwerkToegangObject
from otlmow_model.Classes.Abstracten.RHZModule import RHZModule
from otlmow_model.Classes.Abstracten.SerienummerObject import SerienummerObject
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.KlAlarmModuleMerk import KlAlarmModuleMerk
from otlmow_model.Datatypes.KlAlarmModuleModelnaam import KlAlarmModuleModelnaam
from otlmow_model.BaseClasses.NonNegIntegerField import NonNegIntegerField


# Generated with OTLClassCreator. To modify: extend, do not edit
class AlarmModule(AIMNaamObject, IPNetwerkToegangObject, RHZModule, SerienummerObject):
    """Module binnen een installatie, waar de verschillende alarmen van andere modules toekomen, en die via het netwerk doorgestuurd kunnen worden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#AlarmModule'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMNaamObject.__init__(self)
        IPNetwerkToegangObject.__init__(self)
        RHZModule.__init__(self)
        SerienummerObject.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkpoort')

        self._aantalAlarmen = OTLAttribuut(field=NonNegIntegerField,
                                           naam='aantalAlarmen',
                                           label='aantal alarmen',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#AlarmModule.aantalAlarmen',
                                           definition='Het aantal verschillende configureerbare alarmen dat de alarmmodule telt.',
                                           owner=self)

        self._merk = OTLAttribuut(field=KlAlarmModuleMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#AlarmModule.merk',
                                  definition='Merknaam van de alarm module.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlAlarmModuleModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#AlarmModule.modelnaam',
                                       definition='Modelnaam van de alarm module.',
                                       owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#AlarmModule.technischeFiche',
                                             definition='De technische fiche van de alarm module.',
                                             owner=self)

    @property
    def aantalAlarmen(self) -> int:
        """Het aantal verschillende configureerbare alarmen dat de alarmmodule telt."""
        return self._aantalAlarmen.get_waarde()

    @aantalAlarmen.setter
    def aantalAlarmen(self, value):
        self._aantalAlarmen.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Merknaam van de alarm module."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """Modelnaam van de alarm module."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van de alarm module."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.BaseClasses.IntegerField import IntegerField
from otlmow_model.Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Verankeringslandhoofd(AIMObject, VlakGeometrie):
    """De verankeringsconstructie aan het einde van een cementbetonverharding."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verankeringslandhoofd'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMObject.__init__(self)
        VlakGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cementbetonverharding')

        self._breedte = OTLAttribuut(field=KwantWrdInMeter,
                                     naam='breedte',
                                     label='breedte',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verankeringslandhoofd.breedte',
                                     definition='De breedte van het verankeringslandhoofd in meter.',
                                     owner=self)

        self._lengte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='lengte',
                                    label='lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verankeringslandhoofd.lengte',
                                    definition='De lengte van het verankeringslandhoofd in meter.',
                                    owner=self)

        self._ribben = OTLAttribuut(field=IntegerField,
                                    naam='ribben',
                                    label='ribben',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verankeringslandhoofd.ribben',
                                    definition='Het aantal ribben van het verankeringslandhoofd.',
                                    owner=self)

    @property
    def breedte(self) -> KwantWrdInMeterWaarden:
        """De breedte van het verankeringslandhoofd in meter."""
        return self._breedte.get_waarde()

    @breedte.setter
    def breedte(self, value):
        self._breedte.set_waarde(value, owner=self)

    @property
    def lengte(self) -> KwantWrdInMeterWaarden:
        """De lengte van het verankeringslandhoofd in meter."""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def ribben(self) -> int:
        """Het aantal ribben van het verankeringslandhoofd."""
        return self._ribben.get_waarde()

    @ribben.setter
    def ribben(self, value):
        self._ribben.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlContactpuntType(KeuzelijstField):
    """Keuzelijst voor types van deurcontacten volgens de gebruikte techniek."""
    naam = 'KlContactpuntType'
    label = 'Contactpunt type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlContactpuntType'
    definition = 'Keuzelijst voor types van deurcontacten volgens de gebruikte techniek.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlContactpuntType'
    options = {
        'deurcontact': KeuzelijstWaarde(invulwaarde='deurcontact',
                                        label='deurcontact',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlContactpuntType/deurcontact'),
        'magneetcontact': KeuzelijstWaarde(invulwaarde='magneetcontact',
                                           label='magneetcontact',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlContactpuntType/magneetcontact')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.Datatypes.KlFolieType import KlFolieType
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class RetroreflecterendeFolie(AIMObject, PuntGeometrie):
    """Retroreflecterend bekledingsmateriaal, bijvoorbeeld van een divergentiepuntbebakeningselement, retroreflecterende koker, of het beeldvlak van een retroreflecterend verkeersbord."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#RetroreflecterendeFolie'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMObject.__init__(self)
        PuntGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Divergentiepuntbebakeningselement')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#RetroReflecterendeKoker')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#RetroreflecterendVerkeersbord')

        self._folietype = OTLAttribuut(field=KlFolieType,
                                       naam='folietype',
                                       label='folietype',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#RetroreflecterendeFolie.folietype',
                                       definition='Het type folie dat bevestigd is aan het retroreflecterend verkeersbord.',
                                       owner=self)

    @property
    def folietype(self) -> str:
        """Het type folie dat bevestigd is aan het retroreflecterend verkeersbord."""
        return self._folietype.get_waarde()

    @folietype.setter
    def folietype(self, value):
        self._folietype.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.Communicatieapparatuur import Communicatieapparatuur
from otlmow_model.Datatypes.KlAntenneConstructieType import KlAntenneConstructieType
from otlmow_model.Datatypes.KlAntenneFrequentierange import KlAntenneFrequentierange
from otlmow_model.Datatypes.KlAntenneMerk import KlAntenneMerk
from otlmow_model.Datatypes.KlAntenneModelnaam import KlAntenneModelnaam
from otlmow_model.Datatypes.KlAntenneUitvoeringsType import KlAntenneUitvoeringsType
from otlmow_model.Datatypes.KwantWrdInDecimaleGraden import KwantWrdInDecimaleGraden, KwantWrdInDecimaleGradenWaarden
from otlmow_model.Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Antenne(Communicatieapparatuur):
    """Toestel verbonden met een zender of ontvanger ten behoeve van het opvangen of verspreiden van signalen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Antenne'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Draagconstructie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Flitspaal')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingsbeugel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wegkantkast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Zendmast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#RHZModule')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Antenne')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Antennecoupler')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PTRegelaar')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SignaalSplitter')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verkeersregelaar')

        self._constructieType = OTLAttribuut(field=KlAntenneConstructieType,
                                             naam='constructieType',
                                             label='constructie type',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Antenne.constructieType',
                                             definition='Het constructie type of de vorm van de antenne, die mee de wijze van ophanging bepaald.',
                                             owner=self)

        self._frequentierange = OTLAttribuut(field=KlAntenneFrequentierange,
                                             naam='frequentierange',
                                             label='frequentierange',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Antenne.frequentierange',
                                             definition='Geeft de frequentierange aan waarbinnen de antenne gebruikt kan worden.',
                                             owner=self)

        self._merk = OTLAttribuut(field=KlAntenneMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Antenne.merk',
                                  definition='Het merk van de antenne.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlAntenneModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Antenne.modelnaam',
                                       definition='De modelnaam/product range van een antenne.',
                                       owner=self)

        self._opstelhoogte = OTLAttribuut(field=KwantWrdInMeter,
                                          naam='opstelhoogte',
                                          label='opstelhoogte',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Antenne.opstelhoogte',
                                          definition='De opstelhoogte van de antenne t.o.v. het maaiveld.',
                                          owner=self)

        self._stralingshoek = OTLAttribuut(field=KwantWrdInDecimaleGraden,
                                           naam='stralingshoek',
                                           label='stralingshoek',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Antenne.stralingshoek',
                                           definition='Geeft aan over welke hoek de antenne signalen kan uitstralen en ontvangen.',
                                           owner=self)

        self._uitvoeringsType = OTLAttribuut(field=KlAntenneUitvoeringsType,
                                             naam='uitvoeringsType',
                                             label='uitvoeringstype',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Antenne.uitvoeringsType',
                                             definition='Het uitvoeringstype betreft de werkwijze van de antenne, die bepaalt onder welke richting(en) de antenne signaal uitstuurt en ontvangt.',
                                             owner=self)

    @property
    def constructieType(self) -> str:
        """Het constructie type of de vorm van de antenne, die mee de wijze van ophanging bepaald."""
        return self._constructieType.get_waarde()

    @constructieType.setter
    def constructieType(self, value):
        self._constructieType.set_waarde(value, owner=self)

    @property
    def frequentierange(self) -> str:
        """Geeft de frequentierange aan waarbinnen de antenne gebruikt kan worden."""
        return self._frequentierange.get_waarde()

    @frequentierange.setter
    def frequentierange(self, value):
        self._frequentierange.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de antenne."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam/product range van een antenne."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def opstelhoogte(self) -> KwantWrdInMeterWaarden:
        """De opstelhoogte van de antenne t.o.v. het maaiveld."""
        return self._opstelhoogte.get_waarde()

    @opstelhoogte.setter
    def opstelhoogte(self, value):
        self._opstelhoogte.set_waarde(value, owner=self)

    @property
    def stralingshoek(self) -> KwantWrdInDecimaleGradenWaarden:
        """Geeft aan over welke hoek de antenne signalen kan uitstralen en ontvangen."""
        return self._stralingshoek.get_waarde()

    @stralingshoek.setter
    def stralingshoek(self, value):
        self._stralingshoek.set_waarde(value, owner=self)

    @property
    def uitvoeringsType(self) -> str:
        """Het uitvoeringstype betreft de werkwijze van de antenne, die bepaalt onder welke richting(en) de antenne signaal uitstuurt en ontvangt."""
        return self._uitvoeringsType.get_waarde()

    @uitvoeringsType.setter
    def uitvoeringsType(self, value):
        self._uitvoeringsType.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSierbeplantingType(KeuzelijstField):
    """Verschillende types van sierbeplanting."""
    naam = 'KlSierbeplantingType'
    label = 'Sierbeplanting type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlSierbeplantingType'
    definition = 'Verschillende types van sierbeplanting.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSierbeplantingType'
    options = {
        'bodembedekkers': KeuzelijstWaarde(invulwaarde='bodembedekkers',
                                           label='bodembedekkers',
                                           status='ingebruik',
                                           definitie='Aangelegd begroeiingstype, doorgaans met vaste planten, die bedoeld is om snel de bodem af te dekken.',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSierbeplantingType/bodembedekkers'),
        'bol-en-knolgewassen': KeuzelijstWaarde(invulwaarde='bol-en-knolgewassen',
                                                label='bol- en knolgewassen',
                                                status='ingebruik',
                                                definitie="Bol- en knolgewassen beschikken over boven- of ondergrondse delen waarin voedsel voor 'barre' tijden kan worden opgeslagen.",
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSierbeplantingType/bol-en-knolgewassen'),
        'siergrassen': KeuzelijstWaarde(invulwaarde='siergrassen',
                                        label='siergrassen',
                                        status='ingebruik',
                                        definitie='Grasachtige planten, doorgaans vaste planten, met een decoratieve waarde. Niet geplant als gazon',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSierbeplantingType/siergrassen'),
        'vaste-planten': KeuzelijstWaarde(invulwaarde='vaste-planten',
                                          label='vaste planten',
                                          status='ingebruik',
                                          definitie='Begroeiingstype met planten die een kruidachtige stengel hebben en overblijvend zijn. Dus niet de eenjarige en tweejarige kruidachtige soorten.',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSierbeplantingType/vaste-planten')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.Draagconstructie import Draagconstructie
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.Datatypes.KlOperationeleStatus import KlOperationeleStatus
from otlmow_model.Datatypes.KlVerkeersbordsteunType import KlVerkeersbordsteunType
from otlmow_model.Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.BaseClasses.StringField import StringField
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Verkeersbordsteun(AIMNaamObject, Draagconstructie, PuntGeometrie):
    """Een draagconstructie voor verkeersborden. Dit kan een ronde paal of een vakwerksteun zijn."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verkeersbordsteun'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMNaamObject.__init__(self)
        Draagconstructie.__init__(self)
        PuntGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Funderingsmassief')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#RetroReflecterendeKoker')

        self._breedte = OTLAttribuut(field=KwantWrdInMillimeter,
                                     naam='breedte',
                                     label='breedte',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verkeersbordsteun.breedte',
                                     usagenote='De breedte van een verkeersbordsteun wordt vooral gebruikt wanneer de verkeersbordsteun van het type vakwerksteun is.',
                                     definition='De breedte van een verkeersbordsteun in millimeter.',
                                     owner=self)

        self._diameter = OTLAttribuut(field=KwantWrdInMillimeter,
                                      naam='diameter',
                                      label='diameter',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verkeersbordsteun.diameter',
                                      definition='De diameter van de verkeersbordpaal in millimeter.',
                                      owner=self)

        self._fabricagevoorschrift = OTLAttribuut(field=StringField,
                                                  naam='fabricagevoorschrift',
                                                  label='fabricagevoorschrift',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verkeersbordsteun.fabricagevoorschrift',
                                                  definition='Genormaliseerde referentie waaraan het infrastructuur element aan voldoet.',
                                                  owner=self)

        self._lengte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='lengte',
                                    label='lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verkeersbordsteun.lengte',
                                    definition='De lengte van de verkeersbordpaal in meter.',
                                    owner=self)

        self._lengteBovengronds = OTLAttribuut(field=KwantWrdInMeter,
                                               naam='lengteBovengronds',
                                               label='lengte bovengronds',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verkeersbordsteun.lengteBovengronds',
                                               definition='De bovengrondse lengte van de verkeersbordpaal in meter.',
                                               owner=self)

        self._lengteOndergronds = OTLAttribuut(field=KwantWrdInMeter,
                                               naam='lengteOndergronds',
                                               label='lengte ondergronds',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verkeersbordsteun.lengteOndergronds',
                                               definition='De ondergrondse lengte van de verkeersbordpaal in meter.',
                                               owner=self)

        self._operationeleStatus = OTLAttribuut(field=KlOperationeleStatus,
                                                naam='operationeleStatus',
                                                label='operationele status',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verkeersbordsteun.operationeleStatus',
                                                usagenote='Attribuut uit gebruik sinds versie 2.0.0 ',
                                                deprecated_version='2.0.0',
                                                definition='De operationele status van de verkeersbordsteun.',
                                                owner=self)

        self._type = OTLAttribuut(field=KlVerkeersbordsteunType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verkeersbordsteun.type',
                                  definition='Het type verkeersbordpaal.',
                                  owner=self)

        self._wanddikte = OTLAttribuut(field=KwantWrdInMillimeter,
                                       naam='wanddikte',
                                       label='wanddikte',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verkeersbordsteun.wanddikte',
                                       definition='De dikte van de wand in millimeter.',
                                       owner=self)

    @property
    def breedte(self) -> KwantWrdInMillimeterWaarden:
        """De breedte van een verkeersbordsteun in millimeter."""
        return self._breedte.get_waarde()

    @breedte.setter
    def breedte(self, value):
        self._breedte.set_waarde(value, owner=self)

    @property
    def diameter(self) -> KwantWrdInMillimeterWaarden:
        """De diameter van de verkeersbordpaal in millimeter."""
        return self._diameter.get_waarde()

    @diameter.setter
    def diameter(self, value):
        self._diameter.set_waarde(value, owner=self)

    @property
    def fabricagevoorschrift(self) -> str:
        """Genormaliseerde referentie waaraan het infrastructuur element aan voldoet."""
        return self._fabricagevoorschrift.get_waarde()

    @fabricagevoorschrift.setter
    def fabricagevoorschrift(self, value):
        self._fabricagevoorschrift.set_waarde(value, owner=self)

    @property
    def lengte(self) -> KwantWrdInMeterWaarden:
        """De lengte van de verkeersbordpaal in meter."""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def lengteBovengronds(self) -> KwantWrdInMeterWaarden:
        """De bovengrondse lengte van de verkeersbordpaal in meter."""
        return self._lengteBovengronds.get_waarde()

    @lengteBovengronds.setter
    def lengteBovengronds(self, value):
        self._lengteBovengronds.set_waarde(value, owner=self)

    @property
    def lengteOndergronds(self) -> KwantWrdInMeterWaarden:
        """De ondergrondse lengte van de verkeersbordpaal in meter."""
        return self._lengteOndergronds.get_waarde()

    @lengteOndergronds.setter
    def lengteOndergronds(self, value):
        self._lengteOndergronds.set_waarde(value, owner=self)

    @property
    def operationeleStatus(self) -> str:
        """De operationele status van de verkeersbordsteun."""
        return self._operationeleStatus.get_waarde()

    @operationeleStatus.setter
    def operationeleStatus(self, value):
        self._operationeleStatus.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Het type verkeersbordpaal."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)

    @property
    def wanddikte(self) -> KwantWrdInMillimeterWaarden:
        """De dikte van de wand in millimeter."""
        return self._wanddikte.get_waarde()

    @wanddikte.setter
    def wanddikte(self, value):
        self._wanddikte.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlDolomietType(KeuzelijstField):
    """Types van dolomiet."""
    naam = 'KlDolomietType'
    label = 'Dolomiet type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlDolomietType'
    definition = 'Types van dolomiet.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlDolomietType'
    options = {
        '0-15': KeuzelijstWaarde(invulwaarde='0-15',
                                 label='0-15',
                                 status='ingebruik',
                                 definitie='0/15',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDolomietType/0-15'),
        '0-5': KeuzelijstWaarde(invulwaarde='0-5',
                                label='0-5',
                                status='ingebruik',
                                definitie='0/5',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDolomietType/0-5'),
        '5-15': KeuzelijstWaarde(invulwaarde='5-15',
                                 label='5-15',
                                 status='ingebruik',
                                 definitie='mei-15',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDolomietType/5-15')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.Classes.Abstracten.Bebakening import Bebakening
from otlmow_model.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class ReflectorInLijnvormigElement(Bebakening, LijnGeometrie):
    """Een reflector dat deel uitmaakt van een constructie met als doel de zichtbaarheid van deze constructie te verhogen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ReflectorInLijnvormigElement'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        Bebakening.__init__(self)
        LijnGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kantopsluiting')



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBVLaagtype(KeuzelijstField):
    """Laagtypes van de bitumineuze verharding."""
    naam = 'KlBVLaagtype'
    label = 'BV laagtype'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBVLaagtype'
    definition = 'Laagtypes van de bitumineuze verharding.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBVLaagtype'
    options = {
        'andere-toplagen': KeuzelijstWaarde(invulwaarde='andere-toplagen',
                                            label='andere toplagen',
                                            status='ingebruik',
                                            definitie='union type om het laagtype van bitumineuze verharding te bepalen',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVLaagtype/andere-toplagen'),
        'beschermingslaag': KeuzelijstWaarde(invulwaarde='beschermingslaag',
                                             label='beschermingslaag',
                                             status='ingebruik',
                                             definitie='beschermingslaag',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVLaagtype/beschermingslaag'),
        'onderlaag': KeuzelijstWaarde(invulwaarde='onderlaag',
                                      label='onderlaag',
                                      status='ingebruik',
                                      definitie='Onderliggende laag van een bitumineuze verharding met een constante dikte. ',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVLaagtype/onderlaag'),
        'profileerlaag': KeuzelijstWaarde(invulwaarde='profileerlaag',
                                          label='profileerlaag',
                                          status='ingebruik',
                                          definitie='union type om het laagtype van bitumineuze verharding te bepalen',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVLaagtype/profileerlaag'),
        'toplaag-van-asfaltbeton': KeuzelijstWaarde(invulwaarde='toplaag-van-asfaltbeton',
                                                    label='toplaag van asfaltbeton',
                                                    status='ingebruik',
                                                    definitie='Bovenste laag van een bitumineuze verharding, die direct in contact komt met het verkeer bestaande uit asfaltbeton.',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVLaagtype/toplaag-van-asfaltbeton'),
        'toplaag-van-gietasfalt': KeuzelijstWaarde(invulwaarde='toplaag-van-gietasfalt',
                                                   label='toplaag van gietasfalt',
                                                   status='ingebruik',
                                                   definitie='union type om het laagtype van bitumineuze verharding te bepalen',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVLaagtype/toplaag-van-gietasfalt'),
        'tussenlaag': KeuzelijstWaarde(invulwaarde='tussenlaag',
                                       label='tussenlaag',
                                       status='ingebruik',
                                       definitie='Bitumineuze laag die aangebracht wordt tussen een betonverharding en de fundering. ',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVLaagtype/tussenlaag')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlWIMDataloggerMerk(KeuzelijstField):
    """Het merk van de WIM-datalogger."""
    naam = 'KlWIMDataloggerMerk'
    label = 'WIM-datalogger merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlWIMDataloggerMerk'
    definition = 'Het merk van de WIM-datalogger.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlWIMDataloggerMerk'
    options = {
        'kistler': KeuzelijstWaarde(invulwaarde='kistler',
                                    label='Kistler',
                                    status='ingebruik',
                                    definitie='Kistler',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWIMDataloggerMerk/kistler')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Muurdoorgangsstuk(AIMObject, PuntGeometrie):
    """Een hulpstuk als doorgang die zorgt voor een volledige verankering en een volledig waterdichte doorvoering van een persleiding door de wanden van de toegangs- of verbindingsputten."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Muurdoorgangsstuk'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMObject.__init__(self)
        PuntGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Persleiding')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Pomp')



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.Voedingspunt import Voedingspunt
from otlmow_model.Datatypes.DtcAfmetingBxlxhInMm import DtcAfmetingBxlxhInMm, DtcAfmetingBxlxhInMmWaarden
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Dieselgenerator(Voedingspunt, PuntGeometrie, VlakGeometrie):
    """Dieselmotor die een generator (machine die mechanische energie omzet in elektrische energie) aandrijft,typisch gebruikt als noodstroom aggregaat bij het wegvallen van de normale netvoeding."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Dieselgenerator'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        Voedingspunt.__init__(self)
        PuntGeometrie.__init__(self)
        VlakGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring')

        self._afmetingen = OTLAttribuut(field=DtcAfmetingBxlxhInMm,
                                        naam='afmetingen',
                                        label='afmetingen',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Dieselgenerator.afmetingen',
                                        definition='De afmetingen van de dieselgenerator.',
                                        owner=self)

    @property
    def afmetingen(self) -> DtcAfmetingBxlxhInMmWaarden:
        """De afmetingen van de dieselgenerator."""
        return self._afmetingen.get_waarde()

    @afmetingen.setter
    def afmetingen(self, value):
        self._afmetingen.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLEKantopsluitingBijkomendeParameter(KeuzelijstField):
    """Gedetailleerder typeren van de kantopsluiting."""
    naam = 'KlLEKantopsluitingBijkomendeParameter'
    label = 'Kantopsluiting bijkomende parameter'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLEKantopsluitingBijkomendeParameter'
    definition = 'Gedetailleerder typeren van de kantopsluiting.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLEKantopsluitingBijkomendeParameter'
    options = {
        'eindschikking-voor-schampkant': KeuzelijstWaarde(invulwaarde='eindschikking-voor-schampkant',
                                                          label='eindschikking voor schampkant',
                                                          status='ingebruik',
                                                          definitie='eindschikking voor schampkant',
                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/eindschikking-voor-schampkant'),
        'gebogen-kantstrook-of-watergreppel-straal-groter-5m': KeuzelijstWaarde(invulwaarde='gebogen-kantstrook-of-watergreppel-straal-groter-5m',
                                                                                label='gebogen kantstrook of watergreppel straal groter 5m',
                                                                                status='ingebruik',
                                                                                definitie='gebogen kantstrook of watergreppel, met straal groter dan 5m',
                                                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/gebogen-kantstrook-of-watergreppel-straal-groter-5m'),
        'gebogen-kantstrook-of-watergreppel-straal-kleiner-of-gelijk-5m': KeuzelijstWaarde(invulwaarde='gebogen-kantstrook-of-watergreppel-straal-kleiner-of-gelijk-5m',
                                                                                           label='gebogen kantstrook of watergreppel straal kleiner of gelijk 5m',
                                                                                           status='ingebruik',
                                                                                           definitie='gebogen kantstrook of watergreppel, met straal kleiner of gelijk 5m',
                                                                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/gebogen-kantstrook-of-watergreppel-straal-kleiner-of-gelijk-5m'),
        'gebogen-trottoirband-of-Trottoirband-watergreppel-straal-groter-5m': KeuzelijstWaarde(invulwaarde='gebogen-trottoirband-of-Trottoirband-watergreppel-straal-groter-5m',
                                                                                               label='gebogen trottoirband of Trottoirband-watergreppel straal groter 5m',
                                                                                               status='ingebruik',
                                                                                               definitie='Gebogen trottoirband of trottoirband-watergreppel, met straal groter dan 5 m.',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/gebogen-trottoirband-of-Trottoirband-watergreppel-straal-groter-5m'),
        'gebogen-trottoirband-of-Trottoirband-watergreppel-straal-groter-5m-reflectoren-schuin': KeuzelijstWaarde(invulwaarde='gebogen-trottoirband-of-Trottoirband-watergreppel-straal-groter-5m-reflectoren-schuin',
                                                                                                                  label='gebogen trottoirband of Trottoirband-watergreppel straal groter 5m reflectoren schuin',
                                                                                                                  status='ingebruik',
                                                                                                                  definitie='Gebogen trottoirband of trottoirband-watergreppel, met straal groter dan 5 m met schuin geplaatste reflectoren.',
                                                                                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/gebogen-trottoirband-of-Trottoirband-watergreppel-straal-groter-5m-reflectoren-schuin'),
        'gebogen-trottoirband-of-Trottoirband-watergreppel-straal-groter-5m-reflectoren-verticaal': KeuzelijstWaarde(invulwaarde='gebogen-trottoirband-of-Trottoirband-watergreppel-straal-groter-5m-reflectoren-verticaal',
                                                                                                                     label='gebogen trottoirband of Trottoirband-watergreppel straal groter 5m reflectoren verticaal',
                                                                                                                     status='ingebruik',
                                                                                                                     definitie='Gebogen trottoirband of trottoirband-watergreppel, met straal groter dan 5 m met verticaal geplaatste reflectoren.',
                                                                                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/gebogen-trottoirband-of-Trottoirband-watergreppel-straal-groter-5m-reflectoren-verticaal'),
        'gebogen-trottoirband-of-Trottoirband-watergreppel-straal-kleiner-of-gelijk-5m': KeuzelijstWaarde(invulwaarde='gebogen-trottoirband-of-Trottoirband-watergreppel-straal-kleiner-of-gelijk-5m',
                                                                                                          label='gebogen trottoirband of Trottoirband-watergreppel straal kleiner of gelijk 5m',
                                                                                                          status='ingebruik',
                                                                                                          definitie='gebogen trottoirband of trottoirband-watergreppel, met straal kleiner of gelijk aan 5m',
                                                                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/gebogen-trottoirband-of-Trottoirband-watergreppel-straal-kleiner-of-gelijk-5m'),
        'gebogen-trottoirband-of-Trottoirband-watergreppel-straal-kleiner-of-gelijk-5m-reflectoren-schuin': KeuzelijstWaarde(invulwaarde='gebogen-trottoirband-of-Trottoirband-watergreppel-straal-kleiner-of-gelijk-5m-reflectoren-schuin',
                                                                                                                             label='gebogen trottoirband of Trottoirband-watergreppel straal kleiner of gelijk 5m reflectoren schuin',
                                                                                                                             status='ingebruik',
                                                                                                                             definitie='Gebogen trottoirband of trottoirband-watergreppel, met straal kleiner of gelijk aan 5m en schuin geplaatste reflectoren.',
                                                                                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/gebogen-trottoirband-of-Trottoirband-watergreppel-straal-kleiner-of-gelijk-5m-reflectoren-schuin'),
        'gebogen-trottoirband-of-Trottoirband-watergreppel-straal-kleiner-of-gelijk-5m-reflectoren-verticaal': KeuzelijstWaarde(invulwaarde='gebogen-trottoirband-of-Trottoirband-watergreppel-straal-kleiner-of-gelijk-5m-reflectoren-verticaal',
                                                                                                                                label='gebogen trottoirband of Trottoirband-watergreppel straal kleiner of gelijk 5m reflectoren verticaal',
                                                                                                                                status='ingebruik',
                                                                                                                                definitie='Gebogen trottoirband of trottoirband-watergreppel, met straal kleiner of gelijk aan 5m met verticaal geplaatste reflectoren.',
                                                                                                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/gebogen-trottoirband-of-Trottoirband-watergreppel-straal-kleiner-of-gelijk-5m-reflectoren-verticaal'),
        'hoekstukken.-hoek-90°-of-270°': KeuzelijstWaarde(invulwaarde='hoekstukken.-hoek-90°-of-270°',
                                                          label='hoekstukken. hoek 90° of 270°',
                                                          status='ingebruik',
                                                          definitie='hoekstukken waarbij de hoek gelijk is aan 90° of 270°',
                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/hoekstukken.-hoek-90°-of-270°'),
        'hoekstukken.-hoek-verschillend-90°-of-270°': KeuzelijstWaarde(invulwaarde='hoekstukken.-hoek-verschillend-90°-of-270°',
                                                                       label='hoekstukken. hoek verschillend 90° of 270°',
                                                                       status='ingebruik',
                                                                       definitie='Hoekstukken, hoek verschillend van 90° of 270°',
                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/hoekstukken.-hoek-verschillend-90°-of-270°'),
        'overgangstrottoirbanden': KeuzelijstWaarde(invulwaarde='overgangstrottoirbanden',
                                                    label='overgangstrottoirbanden',
                                                    status='ingebruik',
                                                    definitie='Overgangstrottoirbanden',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/overgangstrottoirbanden'),
        'rechte-kantstrook-of-watergreppel': KeuzelijstWaarde(invulwaarde='rechte-kantstrook-of-watergreppel',
                                                              label='rechte kantstrook of watergreppel',
                                                              status='ingebruik',
                                                              definitie='Rechte kantstrook of watergreppel.',
                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/rechte-kantstrook-of-watergreppel'),
        'rechte-schampkant': KeuzelijstWaarde(invulwaarde='rechte-schampkant',
                                              label='rechte schampkant',
                                              status='ingebruik',
                                              definitie='rechte schampkant',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/rechte-schampkant'),
        'rechte-trottoirband-of-Trottoirband-watergreppel-reflectoren-schuin': KeuzelijstWaarde(invulwaarde='rechte-trottoirband-of-Trottoirband-watergreppel-reflectoren-schuin',
                                                                                                label='rechte trottoirband of Trottoirband-watergreppel reflectoren schuin',
                                                                                                status='ingebruik',
                                                                                                definitie='Rechte trottoirband of trottoirband-watergreppel met schuin geplaatste reflectoren.',
                                                                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/rechte-trottoirband-of-Trottoirband-watergreppel-reflectoren-schuin'),
        'rechte-trottoirband-of-trottoirband-watergreppel': KeuzelijstWaarde(invulwaarde='rechte-trottoirband-of-trottoirband-watergreppel',
                                                                             label='rechte trottoirband of trottoirband-watergreppel',
                                                                             status='ingebruik',
                                                                             definitie='Rechte trottoirband of trottoirband-watergreppel.',
                                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/rechte-trottoirband-of-trottoirband-watergreppel'),
        'rechte-trottoirband-of-trottoirbandwater-greppel-reflectoren-verticaal': KeuzelijstWaarde(invulwaarde='rechte-trottoirband-of-trottoirbandwater-greppel-reflectoren-verticaal',
                                                                                                   label='rechte trottoirband of trottoirbandwater-greppel reflectoren verticaal',
                                                                                                   status='ingebruik',
                                                                                                   definitie='Rechte trottoirband of trottoirband-watergreppel met verticaal geplaatste reflectoren.',
                                                                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/rechte-trottoirband-of-trottoirbandwater-greppel-reflectoren-verticaal'),
        'supplement-voor-in-verstek-zagen': KeuzelijstWaarde(invulwaarde='supplement-voor-in-verstek-zagen',
                                                             label='supplement voor in verstek zagen',
                                                             status='ingebruik',
                                                             definitie='supplement voor in verstek zagen',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/supplement-voor-in-verstek-zagen'),
        'trottoirbanden-voor-minder-validen': KeuzelijstWaarde(invulwaarde='trottoirbanden-voor-minder-validen',
                                                               label='trottoirbanden voor minder-validen',
                                                               status='ingebruik',
                                                               definitie='trottoirbanden voor minder-validen',
                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingBijkomendeParameter/trottoirbanden-voor-minder-validen')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from typing import List
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from abc import abstractmethod
from otlmow_model.Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.Datatypes.DtcAdres import DtcAdres, DtcAdresWaarden
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.DtcExterneReferentie import DtcExterneReferentie, DtcExterneReferentieWaarden
from otlmow_model.Datatypes.KlVerkeerstekenWettelijkeStatus import KlVerkeerstekenWettelijkeStatus
from otlmow_model.BaseClasses.StringField import StringField
from otlmow_model.GeometrieTypes.GeenGeometrie import GeenGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Verkeersteken(AIMObject, GeenGeometrie):
    """Abstracte klasse voor aanwijzingen ten behoeve van de weggebruikers die verbonden wordt aan het aankondigen of opleggen van een bepaalde verkeersmaatregel zoals bepaald in de wegcode."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersteken'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        AIMObject.__init__(self)
        GeenGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersteken')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VerkeersbordVerkeersteken')

        self._adres = OTLAttribuut(field=DtcAdres,
                                   naam='adres',
                                   label='adres',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersteken.adres',
                                   definition='Adres van het verkeersteken.',
                                   owner=self)

        self._afbeelding = OTLAttribuut(field=DtcDocument,
                                        naam='afbeelding',
                                        label='afbeelding',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersteken.afbeelding',
                                        kardinaliteit_min='0',
                                        kardinaliteit_max='*',
                                        definition='Foto van het verkeersteken.',
                                        owner=self)

        self._mobiliteitsMaatregel = OTLAttribuut(field=DtcExterneReferentie,
                                                  naam='mobiliteitsMaatregel',
                                                  label='mobiliteitsmaatregel',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersteken.mobiliteitsMaatregel',
                                                  kardinaliteit_min='0',
                                                  kardinaliteit_max='*',
                                                  definition='Externe referentie naar een maatregel om de beweging en verplaatsing van de weggebruiker op het openbaar domein of privé domein met openbaar karakter te organiseren.',
                                                  owner=self)

        self._plaatsbeschrijving = OTLAttribuut(field=StringField,
                                                naam='plaatsbeschrijving',
                                                label='plaatsbeschrijving',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersteken.plaatsbeschrijving',
                                                definition='Tekstuele beschrijving waar het verkeersteken zal komen.',
                                                owner=self)

        self._signalisatieVergunning = OTLAttribuut(field=DtcExterneReferentie,
                                                    naam='signalisatieVergunning',
                                                    label='signalisatievergunning',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersteken.signalisatieVergunning',
                                                    kardinaliteit_min='0',
                                                    kardinaliteit_max='*',
                                                    definition='Externe referentie naar een vergunning voor het tijdelijk aanbrengen of wijzigen van signalisatie op het openbaar domein of privaat domein met openbaar karakter.',
                                                    owner=self)

        self._variabelOpschrift = OTLAttribuut(field=StringField,
                                               naam='variabelOpschrift',
                                               label='variabel opschrift',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersteken.variabelOpschrift',
                                               definition='Variabele tekst die op het verkeersbordconcept komt te staan.',
                                               owner=self)

        self._wettelijkeStatus = OTLAttribuut(field=KlVerkeerstekenWettelijkeStatus,
                                              naam='wettelijkeStatus',
                                              label='wettelijke status',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersteken.wettelijkeStatus',
                                              usagenote='Bijvoorbeeld: vergund, niet-vergund, in ontwerp',
                                              definition='Duidt de wettelijke status aan van het verkeersteken.',
                                              owner=self)

    @property
    def adres(self) -> DtcAdresWaarden:
        """Adres van het verkeersteken."""
        return self._adres.get_waarde()

    @adres.setter
    def adres(self, value):
        self._adres.set_waarde(value, owner=self)

    @property
    def afbeelding(self) -> List[DtcDocumentWaarden]:
        """Foto van het verkeersteken."""
        return self._afbeelding.get_waarde()

    @afbeelding.setter
    def afbeelding(self, value):
        self._afbeelding.set_waarde(value, owner=self)

    @property
    def mobiliteitsMaatregel(self) -> List[DtcExterneReferentieWaarden]:
        """Externe referentie naar een maatregel om de beweging en verplaatsing van de weggebruiker op het openbaar domein of privé domein met openbaar karakter te organiseren."""
        return self._mobiliteitsMaatregel.get_waarde()

    @mobiliteitsMaatregel.setter
    def mobiliteitsMaatregel(self, value):
        self._mobiliteitsMaatregel.set_waarde(value, owner=self)

    @property
    def plaatsbeschrijving(self) -> str:
        """Tekstuele beschrijving waar het verkeersteken zal komen."""
        return self._plaatsbeschrijving.get_waarde()

    @plaatsbeschrijving.setter
    def plaatsbeschrijving(self, value):
        self._plaatsbeschrijving.set_waarde(value, owner=self)

    @property
    def signalisatieVergunning(self) -> List[DtcExterneReferentieWaarden]:
        """Externe referentie naar een vergunning voor het tijdelijk aanbrengen of wijzigen van signalisatie op het openbaar domein of privaat domein met openbaar karakter."""
        return self._signalisatieVergunning.get_waarde()

    @signalisatieVergunning.setter
    def signalisatieVergunning(self, value):
        self._signalisatieVergunning.set_waarde(value, owner=self)

    @property
    def variabelOpschrift(self) -> str:
        """Variabele tekst die op het verkeersbordconcept komt te staan."""
        return self._variabelOpschrift.get_waarde()

    @variabelOpschrift.setter
    def variabelOpschrift(self, value):
        self._variabelOpschrift.set_waarde(value, owner=self)

    @property
    def wettelijkeStatus(self) -> str:
        """Duidt de wettelijke status aan van het verkeersteken."""
        return self._wettelijkeStatus.get_waarde()

    @wettelijkeStatus.setter
    def wettelijkeStatus(self, value):
        self._wettelijkeStatus.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlAntiparkeerpaalMateriaal(KeuzelijstField):
    """Bepaling van het vervaardigingsmateriaal van de antiparkeerpaal."""
    naam = 'KlAntiparkeerpaalMateriaal'
    label = 'Antiparkeerpaal materiaal'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlAntiparkeerpaalMateriaal'
    definition = 'Bepaling van het vervaardigingsmateriaal van de antiparkeerpaal.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlAntiparkeerpaalMateriaal'
    options = {
        'hout': KeuzelijstWaarde(invulwaarde='hout',
                                 label='hout',
                                 status='ingebruik',
                                 definitie='Keuze hout voor het antiparkeerpaal materiaal.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAntiparkeerpaalMateriaal/hout'),
        'kunststof': KeuzelijstWaarde(invulwaarde='kunststof',
                                      label='kunststof',
                                      status='ingebruik',
                                      definitie='Keuze kunststof voor het antiparkeerpaal materiaal.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAntiparkeerpaalMateriaal/kunststof'),
        'metaal': KeuzelijstWaarde(invulwaarde='metaal',
                                   label='metaal',
                                   status='ingebruik',
                                   definitie='Keuze metaal voor het antiparkeerpaal materiaal.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAntiparkeerpaalMateriaal/metaal')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

